@@ -5,7 +5,7 @@
 import argparse
 from pathlib import Path
 import mtdata
-from mtdata import log
+from mtdata import log, __version__
 from mtdata.data import Dataset, get_entries
 from mtdata.utils import IO
 from mtdata.iso import iso3_code
@@ -29,7 +29,7 @@ def get_data(args):
     cli_sig = f'-l {"-".join(args.langs)}'
     cli_sig += f' -tr {" ".join(args.train_names)}' if args.train_names else ''
     cli_sig += f' -ts {" ".join(args.test_names)}' if args.test_names else ''
-    sig = f'mtdat get {cli_sig} -o <out-dir>\nmtdata version {mtdata.__version__}'
+    sig = f'mtdata get {cli_sig} -o <out-dir>\nmtdata version {mtdata.__version__}\n'
     log.info(f'Dataset is ready at {dataset.dir}')
     log.info(f'mtdata args for reproducing this dataset:\n {sig}')
     with IO.writer(args.out / 'mtdata.signature.txt', append=True) as w:
@@ -68,6 +68,7 @@ def parse_args():
     p = argparse.ArgumentParser(formatter_class=MyFormatter)
     p.add_argument('-c', '--cache', type=Path, help='Cache dir', default=mtdata.cache_dir)
     p.add_argument('-vv', '--verbose', action='store_true', help='verbose mode')
+    p.add_argument('-v', '--version', action='version', version=f'%(prog)s {__version__}')
 
     sub_ps = p.add_subparsers(required=True, dest='task',
                               help='''R|
